BOOST_PP_ENUM_BINARY_PARAMS

The BOOST_PP_ENUM_SHIFTED_BINARY_PARAMS macro generates a comma-separated, shifted list of binary parameters.

#### Usage

BOOST_PP_ENUM_SHIFTED_BINARY_PARAMS(count, p1, p2)

#### Arguments

count
  The number of parameters to generate. Valid values range from 0 to BOOST_PP_LIMIT_REPEAT.
p1
  The text of the first part of the parameter. BOOST_PP_ENUM_SHIFTED_BINARY_PARAMS concatenates numbers ranging from 0 to count - 1 to generate parameters.
p2
  The text of the first part of the parameter. BOOST_PP_ENUM_SHIFTED_BINARY_PARAMS concatenates numbers ranging from 0 to count - 1 to generate parameters.

#### Remarks

This macro expands to the comma-separated sequence:
p1 ## 1 p2 ## 1, p1 ## 2 p2 ## 2, ... p1 ## count - 1 p2 ## count - 1
To use the z parameter passed from other macros that use BOOST_PP_REPEAT, see BOOST_PP_ENUM_SHIFTED_BINARY_PARAMS_Z.

#### See Also

- BOOST_PP_ENUM_SHIFTED_BINARY_PARAMS_Z
- BOOST_PP_LIMIT_REPEAT

#### Requirements

Header: <boost/preprocessor/repetition/enum_shifted_binary_params.hpp>

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)